==> react-molecule-badge-counter-1.10.0.tgz: package/lib/index.js <==
import cx from 'classnames';
import PropTypes from 'prop-types';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BASE_CLASS = "sui-MoleculeBadgeCounter";
var CLASS_WITH_CHILDREN = BASE_CLASS + "--withChildren";
var CLASS_BULLET = BASE_CLASS + "-bullet";
var CLASS_SMALL = CLASS_BULLET + "-small";
var CLASS_MEDIUM = CLASS_BULLET + "-medium";
var CLASS_LARGE = CLASS_BULLET + "-large";
var CLASS_DISABLED = 'is-disabled';
var CLASS_SELECTED = 'is-selected';
var CLASS_MEDIUM_THREE_CHARS = CLASS_MEDIUM + "--threeCharacters";
var CLASS_LARGE_THREE_CHARS = CLASS_LARGE + "--threeCharacters";
var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};
var STATUS = {
  DEFAULT: 'default',
  DISABLED: 'disabled',
  SELECTED: 'selected'
};
var VARIANTS = {
  DOT: 'dot',
  EXCLAMATION: 'exclamation',
  EXTENDED: 'extended'
};
var MAX_LABEL = '+99';

var MoleculeBadgeCounter = function MoleculeBadgeCounter(_ref) {
  var _cx, _cx2;

  var children = _ref.children,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      size = _ref.size,
      status = _ref.status,
      variant = _ref.variant;
  var hasLabel = Boolean(label);
  var hasChildren = Boolean(children);
  var CLASS_SIZE = getClassSize({
    size: size,
    hasLabel: hasLabel
  });
  var CLASS_STATUS = getClassStatus({
    status: status
  });
  var CLASS_LENGTH_LABEL = getClassLengthLabel({
    hasLabel: hasLabel,
    label: label,
    size: size
  });
  var CLASS_VARIANT = variant ? CLASS_BULLET + "-" + variant : '';
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_WITH_CHILDREN] = hasChildren, _cx));
  var processedLabel = label.length >= 3 ? MAX_LABEL : label;
  var classNameBullet = cx(CLASS_BULLET, CLASS_SIZE, CLASS_STATUS, CLASS_VARIANT, CLASS_LENGTH_LABEL, (_cx2 = {}, _cx2[CLASS_WITH_CHILDREN] = Boolean(children), _cx2));
  return /*#__PURE__*/_jsxs("span", {
    className: className,
    children: [/*#__PURE__*/_jsx("span", {
      className: classNameBullet,
      children: processedLabel
    }), /*#__PURE__*/_jsx("span", {
      children: children
    })]
  });
};

var getClassSize = function getClassSize(_ref2) {
  var size = _ref2.size,
      hasLabel = _ref2.hasLabel;

  if (hasLabel && (size === SIZES.SMALL || !size) || size === SIZES.MEDIUM) {
    return CLASS_MEDIUM;
  } else if (size === SIZES.LARGE) {
    return CLASS_LARGE;
  }

  return CLASS_SMALL;
};

var getClassStatus = function getClassStatus(_ref3) {
  var status = _ref3.status;
  if (status === STATUS.DISABLED) return CLASS_DISABLED;
  if (status === STATUS.SELECTED) return CLASS_SELECTED;
  return '';
};

var getClassLengthLabel = function getClassLengthLabel(_ref4) {
  var hasLabel = _ref4.hasLabel,
      label = _ref4.label,
      size = _ref4.size;
  if (!hasLabel || (label + '').length < 3) return '';
  if (size === SIZES.MEDIUM) return CLASS_MEDIUM_THREE_CHARS;
  return CLASS_LARGE_THREE_CHARS;
};

MoleculeBadgeCounter.displayName = 'MoleculeBadgeCounter';
export default MoleculeBadgeCounter;
export { SIZES as moleculeBadgeCounterSizes, STATUS as moleculeBadgeCounterStatus, VARIANTS as moleculeBadgeCounterVariants };

==> react-molecule-badge-counter-1.15.0.tgz: package/lib/index.js <==
import cx from 'classnames';
import PropTypes from 'prop-types';
import { BASE_CLASS, CLASS_BULLET, CLASS_DISABLED, CLASS_LARGE, CLASS_LARGE_THREE_CHARS, CLASS_MEDIUM, CLASS_MEDIUM_THREE_CHARS, CLASS_SELECTED, CLASS_SMALL, CLASS_WITH_CHILDREN, MAX_LABEL, SIZES, STATUS, VARIANTS } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeBadgeCounter = function MoleculeBadgeCounter(_ref) {
  var _cx, _cx2;

  var children = _ref.children,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      _ref$labelMax = _ref.labelMax,
      labelMax = _ref$labelMax === void 0 ? MAX_LABEL : _ref$labelMax,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.MEDIUM : _ref$size,
      status = _ref.status,
      variant = _ref.variant;
  var hasLabel = Boolean(label);
  var hasChildren = Boolean(children);
  var CLASS_SIZE = getClassSize({
    size: size,
    hasLabel: hasLabel
  });
  var CLASS_STATUS = getClassStatus({
    status: status
  });
  var CLASS_LENGTH_LABEL = getClassLengthLabel({
    hasLabel: hasLabel,
    label: label,
    size: size
  });
  var CLASS_VARIANT = variant ? CLASS_BULLET + "-" + variant : '';
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_WITH_CHILDREN] = hasChildren, _cx));
  var processedLabel = parseFloat(label) > parseFloat(labelMax) ? "+" + labelMax : label;
  var classNameBullet = cx(CLASS_BULLET, CLASS_SIZE, CLASS_STATUS, CLASS_VARIANT, CLASS_LENGTH_LABEL, (_cx2 = {}, _cx2[CLASS_WITH_CHILDREN] = Boolean(children), _cx2));
  return /*#__PURE__*/_jsxs("span", {
    className: className,
    children: [/*#__PURE__*/_jsx("span", {
      className: classNameBullet,
      children: processedLabel
    }), /*#__PURE__*/_jsx("span", {
      children: children
    })]
  });
};

var getClassSize = function getClassSize(_ref2) {
  var size = _ref2.size,
      hasLabel = _ref2.hasLabel;

  if (size !== SIZES.SMALL) {
    var _SIZES$MEDIUM$SIZES$L;

    return (_SIZES$MEDIUM$SIZES$L = {}, _SIZES$MEDIUM$SIZES$L[SIZES.MEDIUM] = CLASS_MEDIUM, _SIZES$MEDIUM$SIZES$L[SIZES.LARGE] = CLASS_LARGE, _SIZES$MEDIUM$SIZES$L)[size];
  } else if (hasLabel && size === SIZES.SMALL) {
    return CLASS_MEDIUM;
  }

  return CLASS_SMALL;
};

var getClassStatus = function getClassStatus(_ref3) {
  var status = _ref3.status;
  if (status === STATUS.DISABLED) return CLASS_DISABLED;
  if (status === STATUS.SELECTED) return CLASS_SELECTED;
  return '';
};

var getClassLengthLabel = function getClassLengthLabel(_ref4) {
  var hasLabel = _ref4.hasLabel,
      label = _ref4.label,
      size = _ref4.size;
  if (!hasLabel || (label + '').length < 3) return '';
  if (size === SIZES.MEDIUM) return CLASS_MEDIUM_THREE_CHARS;
  return CLASS_LARGE_THREE_CHARS;
};

MoleculeBadgeCounter.displayName = 'MoleculeBadgeCounter';
export default MoleculeBadgeCounter;
export { SIZES as moleculeBadgeCounterSizes, STATUS as moleculeBadgeCounterStatus, VARIANTS as moleculeBadgeCounterVariants };
